prefix_index_paths

Function prefix_index_paths 

pub fn prefix_index_paths(path: &Path, prefix: &str) -> Result<(), ScipError>
Rewrite document paths from an index produced in a nested project so they remain repo-relative after indexes from several project roots are merged. Indexers generally emit paths relative to their working directory, while Sinter’s nodes are always relative to the repository.